Learn R Programming

rwstats (version 0.1)

wordMiner.next: Occurrence and frequency of the next word

Description

This is a function that lists the next word appearing frequency by a given chinese character based on real world chinese character frequency Statistics table.

Usage

wordMiner.next(candidateWord, topN = 10)

Arguments

candidateWord

A single Chinese character

topN

The number of raws of output dataframe

Value

A dataframe containing the next word and its occurrence and frequency

Examples

Run this code
# NOT RUN {
wordMiner.next(strsplit(levels(twoChar$character)[988], "")[[1]][1])
wordMiner.next(strsplit(levels(twoChar$character)[988], "")[[1]][2], 20)
# }

Run the code above in your browser using DataLab