wordMiner.previous: Occurrence and frequency of the previous word
Description
This is a function that lists the previous word appearing frequency
by a given chinese character based on real world
chinese character frequency Statistics table.
Usage
wordMiner.previous(candidateWord, topN = 10)
Arguments
candidateWord
A single Chinese character
topN
The number of raws of output dataframe
Value
A dataframe containing the previous word and its occurrence and frequency
# NOT RUN {wordMiner.previous(strsplit(levels(twoChar$character)[988], "")[[1]][1])
wordMiner.previous(strsplit(levels(twoChar$character)[988], "")[[1]][2], 20)
# }